==> kubernetes-model-admissionregistration-5.7.3-sources.jar: io/fabric8/kubernetes/api/model/admission/v1beta1/AdmissionReviewFluent.java <==
package io.fabric8.kubernetes.api.model.admission.v1beta1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface AdmissionReviewFluent<A extends io.fabric8.kubernetes.api.model.admission.v1beta1.AdmissionReviewFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public java.lang.String getApiVersion();
  public A withApiVersion(java.lang.String apiVersion);
  public java.lang.Boolean hasApiVersion();
  
  /**
   * Method is deprecated. use withApiVersion instead.
   */
  @java.lang.Deprecated
  public A withNewApiVersion(java.lang.String arg0);
  public java.lang.String getKind();
  public A withKind(java.lang.String kind);
  public java.lang.Boolean hasKind();
  
  /**
   * Method is deprecated. use withKind instead.
   */
  @java.lang.Deprecated
  public A withNewKind(java.lang.String arg0);
  public io.fabric8.kubernetes.api.model.admission.v1beta1.AdmissionRequest getRequest();
  public A withRequest(io.fabric8.kubernetes.api.model.admission.v1beta1.AdmissionRequest request);
  public java.lang.Boolean hasRequest();
  
  /**
   * This method has been deprecated, please use method buildResponse instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.admission.v1beta1.AdmissionResponse getResponse();
  public io.fabric8.kubernetes.api.model.admission.v1beta1.AdmissionResponse buildResponse();
  public A withResponse(io.fabric8.kubernetes.api.model.admission.v1beta1.AdmissionResponse response);
  public java.lang.Boolean hasResponse();
  public io.fabric8.kubernetes.api.model.admission.v1beta1.AdmissionReviewFluent.ResponseNested<A> withNewResponse();
  public io.fabric8.kubernetes.api.model.admission.v1beta1.AdmissionReviewFluent.ResponseNested<A> withNewResponseLike(io.fabric8.kubernetes.api.model.admission.v1beta1.AdmissionResponse item);
  public io.fabric8.kubernetes.api.model.admission.v1beta1.AdmissionReviewFluent.ResponseNested<A> editResponse();
  public io.fabric8.kubernetes.api.model.admission.v1beta1.AdmissionReviewFluent.ResponseNested<A> editOrNewResponse();
  public io.fabric8.kubernetes.api.model.admission.v1beta1.AdmissionReviewFluent.ResponseNested<A> editOrNewResponseLike(io.fabric8.kubernetes.api.model.admission.v1beta1.AdmissionResponse item);
  public interface ResponseNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.admission.v1beta1.AdmissionResponseFluent<io.fabric8.kubernetes.api.model.admission.v1beta1.AdmissionReviewFluent.ResponseNested<N>>{
    public N and();
    public N endResponse();
    
  }
  
}

==> kubernetes-model-admissionregistration-5.12.2-sources.jar: io/fabric8/kubernetes/api/model/admission/v1beta1/AdmissionReviewFluent.java <==
package io.fabric8.kubernetes.api.model.admission.v1beta1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface AdmissionReviewFluent<A extends io.fabric8.kubernetes.api.model.admission.v1beta1.AdmissionReviewFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public java.lang.String getApiVersion();
  public A withApiVersion(java.lang.String apiVersion);
  public java.lang.Boolean hasApiVersion();
  
  /**
   * Method is deprecated. use withApiVersion instead.
   */
  @java.lang.Deprecated
  public A withNewApiVersion(java.lang.String arg0);
  public java.lang.String getKind();
  public A withKind(java.lang.String kind);
  public java.lang.Boolean hasKind();
  
  /**
   * Method is deprecated. use withKind instead.
   */
  @java.lang.Deprecated
  public A withNewKind(java.lang.String arg0);
  public io.fabric8.kubernetes.api.model.admission.v1beta1.AdmissionRequest getRequest();
  public A withRequest(io.fabric8.kubernetes.api.model.admission.v1beta1.AdmissionRequest request);
  public java.lang.Boolean hasRequest();
  
  /**
   * This method has been deprecated, please use method buildResponse instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.admission.v1beta1.AdmissionResponse getResponse();
  public io.fabric8.kubernetes.api.model.admission.v1beta1.AdmissionResponse buildResponse();
  public A withResponse(io.fabric8.kubernetes.api.model.admission.v1beta1.AdmissionResponse response);
  public java.lang.Boolean hasResponse();
  public io.fabric8.kubernetes.api.model.admission.v1beta1.AdmissionReviewFluent.ResponseNested<A> withNewResponse();
  public io.fabric8.kubernetes.api.model.admission.v1beta1.AdmissionReviewFluent.ResponseNested<A> withNewResponseLike(io.fabric8.kubernetes.api.model.admission.v1beta1.AdmissionResponse item);
  public io.fabric8.kubernetes.api.model.admission.v1beta1.AdmissionReviewFluent.ResponseNested<A> editResponse();
  public io.fabric8.kubernetes.api.model.admission.v1beta1.AdmissionReviewFluent.ResponseNested<A> editOrNewResponse();
  public io.fabric8.kubernetes.api.model.admission.v1beta1.AdmissionReviewFluent.ResponseNested<A> editOrNewResponseLike(io.fabric8.kubernetes.api.model.admission.v1beta1.AdmissionResponse item);
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value);
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public A removeFromAdditionalProperties(java.lang.String key);
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties);
  public java.lang.Boolean hasAdditionalProperties();
  public interface ResponseNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.admission.v1beta1.AdmissionResponseFluent<io.fabric8.kubernetes.api.model.admission.v1beta1.AdmissionReviewFluent.ResponseNested<N>>{
    public N and();
    public N endResponse();
    
  }
  
}
